@@ -1,13 +1,12 @@
+from models.model import ClientModel
 import pyodbc
-from abc import ABC, abstractmethod
-class DatabaseClient(ABC):
-    def __init__(self,server,database,username,password,driverLocation):
+class DatabaseClient(ClientModel):
+    def __init__(self, server, database, username, password, driverLocation, *args, **kwargs):
         self.server=server
         self.database=database
         self.username=username
         self.password=password
         self.driverLocation=driverLocation
-        return
         if self.databaseType().lower() == "mssql":
             self.cnxn = pyodbc.connect(
                 "DRIVER="+str(driverLocation)+";"+
@@ -25,6 +24,7 @@ class DatabaseClient(ABC):
                 self.password,
                 self.driverLocation
             )
+        super().__init__(*args, **kwargs)
 
     def getCursor(self):
         return self.cursor
